# Generated by roxygen2: do not edit by hand

export(sample_int_R)
export(sample_int_cccrank)
export(sample_int_ccrank)
export(sample_int_crank)
export(sample_int_expj)
export(sample_int_expjs)
export(sample_int_rank)
export(sample_int_rej)
importFrom(Rcpp,evalCpp)
importFrom(stats,rexp)
importFrom(utils,head)
useDynLib(wrswoR, .registration = TRUE)
