# Generated by using Rcpp::compileAttributes() -> do not edit by hand
# Generator token: 10BE3573-1514-4C36-9D1C-5A225CD40393

#' @rdname sample_int
#' @export
sample_int_crank <- function(n, size, prob) {
    .Call(`_wrswoR_sample_int_crank`, n, size, prob)
}

#' @rdname sample_int
#' @export
sample_int_ccrank <- function(n, size, prob) {
    .Call(`_wrswoR_sample_int_ccrank`, n, size, prob)
}

#' @rdname sample_int
#' @export
sample_int_cccrank <- function(n, size, prob) {
    .Call(`_wrswoR_sample_int_cccrank`, n, size, prob)
}

#' @rdname sample_int
#' @export
sample_int_expj <- function(n, size, prob) {
    .Call(`_wrswoR_sample_int_expj`, n, size, prob)
}

#' @rdname sample_int
#' @export
sample_int_expjs <- function(n, size, prob) {
    .Call(`_wrswoR_sample_int_expjs`, n, size, prob)
}

